@@ -9,9 +9,8 @@
 # This file is part of BayesPy.
 #
 # BayesPy is free software: you can redistribute it and/or modify it
-# under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# under the terms of the GNU General Public License version 3 as
+# published by the Free Software Foundation.
 #
 # BayesPy is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -24,7 +23,5 @@
 
 from . import utils
 from . import inference
-
-# Currently, model construction and the inference network are not separated so
-# the model is constructed using variational message passing nodes.
-from .inference.vmp import nodes
+from . import nodes
+from . import plot
